==> plone_sphinx_theme-0.0.10.tar.gz: plone_sphinx_theme-0.0.10/docs/guides/contributing-policies.md <==
---
myst:
  html_meta:
    "description": "Contributing policies of Plone Sphinx Theme"
    "property=og:description": "Contributing policies of Plone Sphinx Theme"
    "property=og:title": "Contributing policies of Plone Sphinx Theme"
    "keywords": "Plone, contributing, policies, Plone Contributor Agreement, License, Code of Conduct, contribute"
---

# Contributing policies

This document describes the contributing policies of Plone Sphinx Theme.

Contributions to the Plone Sphinx Theme are welcome.

```{seealso}
To contribute code to Plone Sphinx Theme, see {doc}`contribute`.
To develop your own theme based on Plone Sphinx Theme, see {doc}`develop`.
```


(contributing-permission-to-publish-label)=

## Grant permission to publish

Before you contribute, you must give permission to publish your contribution according to the license we use.
You may give that permission by signing the [Plone Contributor Agreement](https://plone.org/foundation/contributors-agreement).
It is a one-time only process.

The Plone Sphinx Theme Documentation is licensed under the [GNU General Public License, version 2 (GPLv2)](https://github.com/plone/plone-sphinx-theme/blob/main/LICENSE.md).
A copy of the license is included in the root of this repository.

A volunteer member of the Plone Foundation will review your signed agreement.

If accepted, your GitHub account will be added to a team in the Plone GitHub organization with appropriate access, and you will simultaneously receive an email notification from GitHub.

Allow up to one week for processing.
Contact the Plone Foundation by its email address for further information, including the status of your request.

```{button-link} https://plone.org/foundation/contributors-agreement
:color: primary

Sign the Plone Contributor Agreement
```

```{seealso}
-   [Plone License FAQ](https://plone.org/foundation/copyright-licensing-logo/license-faq)
```


(contributing-code-of-conduct-label)=

## Code of Conduct

The Plone Foundation has published a [Code of Conduct](https://plone.org/foundation/materials/foundation-resolutions/code-of-conduct).
All contributors to the Plone Documentation follow the Code of Conduct.

==> plone_sphinx_theme-1.2.0.tar.gz: plone_sphinx_theme-1.2.0/docs/guides/contributing-policies.md <==
---
myst:
  html_meta:
    "description": "Contributing policies of Plone Sphinx Theme"
    "property=og:description": "Contributing policies of Plone Sphinx Theme"
    "property=og:title": "Contributing policies of Plone Sphinx Theme"
    "keywords": "Plone, contributing, policies, Plone Contributor Agreement, License, Code of Conduct, contribute"
---

# Contributing policies

This document describes the contributing policies of Plone Sphinx Theme.

Contributions to the Plone Sphinx Theme are welcome.

```{seealso}
To contribute code to Plone Sphinx Theme, see {doc}`contribute`.
To develop your own theme based on Plone Sphinx Theme, see {doc}`develop`.
```


(contributing-permission-to-publish-label)=

## Grant permission to publish

Before you contribute, you must give permission to publish your contribution according to the license that Plone uses.
You may give that permission by signing the [Plone Contributor Agreement](https://plone.org/foundation/contributors-agreement).
It's a one-time only process.

The Plone Sphinx Theme Documentation is licensed under the [GNU General Public License, version 2 (GPLv2)](https://github.com/plone/plone-sphinx-theme/blob/main/LICENSE).
A copy of the license is included in the root of this repository.

A volunteer member of the Plone Foundation will review your signed agreement.

If accepted, your GitHub account will be added to a team in the Plone GitHub organization with appropriate access, and you will simultaneously receive an email from GitHub for you to accept the invitation to join the team.

Allow up to one week for processing.
Contact the Plone Foundation by its email address for further information, including the status of your request.

```{button-link} https://plone.org/foundation/contributors-agreement
:color: primary

Sign the Plone Contributor Agreement
```

```{seealso}
-   [Plone License FAQ](https://plone.org/foundation/copyright-licensing-logo/license-faq)
```


(contributing-code-of-conduct-label)=

## Code of Conduct

The Plone Foundation has published a [Code of Conduct](https://plone.org/foundation/materials/foundation-resolutions/code-of-conduct).
All contributors to the Plone Documentation follow the Code of Conduct.
